.\" $NetBSD: btsco.4,v 1.12.8.1 2019/09/02 16:39:20 martin Exp $
.\"
.\" Copyright (c) 2006 Itronix Inc.
.\" All rights reserved.
.\"
.\" Written by Iain Hibbert for Itronix Inc.
.\"
.\" Redistribution and use in source and binary forms, with or without
.\" modification, are permitted provided that the following conditions
.\" are met:
.\" 1. Redistributions of source code must retain the above copyright
.\"    notice, this list of conditions and the following disclaimer.
.\" 2. Redistributions in binary form must reproduce the above copyright
.\"    notice, this list of conditions and the following disclaimer in the
.\"    documentation and/or other materials provided with the distribution.
.\" 3. The name of Itronix Inc. may not be used to endorse
.\"    or promote products derived from this software without specific
.\"    prior written permission.
.\"
.\" THIS SOFTWARE IS PROVIDED BY ITRONIX INC. ``AS IS'' AND
.\" ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
.\" TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
.\" PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ITRONIX INC. BE LIABLE FOR ANY
.\" DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
.\" (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
.\" LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
.\" ON ANY THEORY OF LIABILITY, WHETHER IN
.\" CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
.\" ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
.\" POSSIBILITY OF SUCH DAMAGE.
.\"
.Dd November 29, 2014
.Dt BTSCO 4
.Os
.Sh NAME
.Nm btsco
.Nd Bluetooth SCO Audio
.Sh SYNOPSIS
.Cd "btsco*	at bthub?"
.Cd "audio*	at audiobus?"
.Sh DESCRIPTION
The
.Nm
driver provides support for Bluetooth SCO (Synchronous connection-oriented)
Audio devices through the
.Xr audio 4
driver.
.Pp
The
.Nm
driver must be configured at run time with the
.Xr btdevctl 8
program.
The following properties are used by the
.Nm
driver during autoconfiguration:
.Pp
.Bl -tag -width listenXX
.It local-bdaddr
Local device address.
.It remote-bdaddr
Remote device address.
.It service-name
The
.Nm
driver matches the
.Sq HF
and
.Sq HSET
services.
For the
.Sq HF
service, the
.Nm
device will, on
.Xr open 2 ,
listen for incoming connections from the remote device.
Otherwise,
.Nm
will attempt to initiate a connection to the remote device.
.It rfcomm-channel
This integer value is not used directly, but will be stored and
passed via the
.Dv BTSCO_INFO
ioctl as below:
.El
.Pp
SCO connections require a baseband connection between the two devices before
they can be created.
The
.Nm
driver does not create this, but can provide information to facilitate
an application setting up a control channel prior to use, via the
.Dv BTSCO_INFO
.Xr ioctl 2
call on the mixer device, which returns a
.Ar btsco_info
structure as follows:
.Bd -literal
#include <dev/bluetooth/btsco.h>

struct btsco_info {
	bdaddr_t	laddr;		/* controller bdaddr */
	bdaddr_t	raddr;		/* headset bdaddr */
	uint8_t		channel;	/* RFCOMM channel */
	int		vgs;		/* mixer index speaker */
	int		vgm;		/* mixer index mic */
};

#define BTSCO_INFO	_IOR('b', 16, struct btsco_info)
.Ed
.Pp
The
.Nm
driver can be configured to act in Connect or Listen mode.
In Connect mode, the
.Nm
driver will initiate a connection to the remote device on an
.Xr open 2
call, whereas in Listen mode,
.Xr open 2
will block until the remote device initiates the connection.
.Sh SEE ALSO
.Xr bthset 1 ,
.Xr ioctl 2 ,
.Xr audio 4 ,
.Xr bluetooth 4 ,
.Xr bthub 4 ,
.Xr btdevctl 8
.Sh HISTORY
The
.Nm
driver
was written for
.Nx 4.0
by
.An Iain Hibbert
under the sponsorship of Itronix, Inc.
.Sh BUGS
.Nm
takes no notice of the HCI Voice Setting in the Bluetooth controller, and this
must be 0x0060 (the default) as alternate values are currently unsupported.
